@@ -1,12 +1,12 @@
 """Docstring"""
 
 from .initialize import (
-    how_to, cleanup, check_git_support, is_git_repo, need_attention, initialize,
+    help, cleanup, check_git_support, is_git_repo, need_attention, initialize,
     )
 
 from .main import (
     Commands, show_repos, load, load_multiple, pull, push, all_status
 )
 
-__all__ = ["how_to", "all_status", "cleanup", "check_git_support", "is_git_repo", "need_attention", "initialize",
+__all__ = ["help", "all_status", "cleanup", "check_git_support", "is_git_repo", "need_attention", "initialize",
            "Commands", "show_repos", "load", "load_multiple", "pull", "push"]
